/* signals.h: Declarations of functions defined in signals.h. */

/*  Copyright (c) 1995 Brian J. Fox
    Author: Brian J. Fox (bfox@ai.mit.edu) Mon Oct  9 05:38:13 1995.  */

#if defined (__cplusplus)
extern "C"
{
#endif

extern void rl_clear_signals (void);
extern void rl_set_signals (void);


#if defined (__cplusplus)
}
#endif
